@@ -218,8 +218,7 @@ CallData::CallData(bool is_client,
   }
 }
 
-void CallData::LogClientHeader(bool is_client,
-                               CallTracerAnnotationInterface* tracer,
+void CallData::LogClientHeader(bool is_client, CallSpan* tracer,
                                const ClientMetadata& metadata) {
   LoggingSink::Entry entry;
   if (!is_client) {
@@ -236,16 +235,14 @@ void CallData::LogClientHeader(bool is_client,
   g_logging_sink->LogEntry(std::move(entry));
 }
 
-void CallData::LogClientHalfClose(bool is_client,
-                                  CallTracerAnnotationInterface* tracer) {
+void CallData::LogClientHalfClose(bool is_client, CallSpan* tracer) {
   LoggingSink::Entry entry;
   SetCommonEntryFields(&entry, is_client, tracer,
                        LoggingSink::Entry::EventType::kClientHalfClose);
   g_logging_sink->LogEntry(std::move(entry));
 }
 
-void CallData::LogServerHeader(bool is_client,
-                               CallTracerAnnotationInterface* tracer,
+void CallData::LogServerHeader(bool is_client, CallSpan* tracer,
                                const ServerMetadata* metadata) {
   LoggingSink::Entry entry;
   if (metadata != nullptr) {
@@ -267,8 +264,7 @@ void CallData::LogServerHeader(bool is_client,
   g_logging_sink->LogEntry(std::move(entry));
 }
 
-void CallData::LogServerTrailer(bool is_client,
-                                CallTracerAnnotationInterface* tracer,
+void CallData::LogServerTrailer(bool is_client, CallSpan* tracer,
                                 const ServerMetadata* metadata) {
   LoggingSink::Entry entry;
   SetCommonEntryFields(&entry, is_client, tracer,
@@ -283,8 +279,7 @@ void CallData::LogServerTrailer(bool is_client,
   g_logging_sink->LogEntry(std::move(entry));
 }
 
-void CallData::LogClientMessage(bool is_client,
-                                CallTracerAnnotationInterface* tracer,
+void CallData::LogClientMessage(bool is_client, CallSpan* tracer,
                                 const SliceBuffer* message) {
   LoggingSink::Entry entry;
   SetCommonEntryFields(&entry, is_client, tracer,
@@ -293,8 +288,7 @@ void CallData::LogClientMessage(bool is_client,
   g_logging_sink->LogEntry(std::move(entry));
 }
 
-void CallData::LogServerMessage(bool is_client,
-                                CallTracerAnnotationInterface* tracer,
+void CallData::LogServerMessage(bool is_client, CallSpan* tracer,
                                 const SliceBuffer* message) {
   LoggingSink::Entry entry;
   SetCommonEntryFields(&entry, is_client, tracer,
@@ -303,8 +297,7 @@ void CallData::LogServerMessage(bool is_client,
   g_logging_sink->LogEntry(std::move(entry));
 }
 
-void CallData::LogCancel(bool is_client,
-                         CallTracerAnnotationInterface* tracer) {
+void CallData::LogCancel(bool is_client, CallSpan* tracer) {
   LoggingSink::Entry entry;
   SetCommonEntryFields(&entry, is_client, tracer,
                        LoggingSink::Entry::EventType::kCancel);
@@ -312,7 +305,7 @@ void CallData::LogCancel(bool is_client,
 }
 
 void CallData::SetCommonEntryFields(LoggingSink::Entry* entry, bool is_client,
-                                    CallTracerAnnotationInterface* tracer,
+                                    CallSpan* tracer,
                                     LoggingSink::Entry::EventType event_type) {
   entry->call_id = call_id_;
   entry->sequence_id = sequence_id_++;
@@ -361,15 +354,14 @@ void ClientLoggingFilter::Call::OnClientInitialMetadata(
     return;
   }
   call_data_->LogClientHeader(
-      /*is_client=*/true, MaybeGetContext<CallTracerAnnotationInterface>(), md);
+      /*is_client=*/true, MaybeGetContext<CallSpan>(), md);
 }
 
 void ClientLoggingFilter::Call::OnServerInitialMetadata(ServerMetadata& md) {
   GRPC_LATENT_SEE_SCOPE("ClientLoggingFilter::Call::OnServerInitialMetadata");
   if (!call_data_.has_value()) return;
   call_data_->LogServerHeader(
-      /*is_client=*/true, MaybeGetContext<CallTracerAnnotationInterface>(),
-      &md);
+      /*is_client=*/true, MaybeGetContext<CallSpan>(), &md);
 }
 
 void ClientLoggingFilter::Call::OnServerTrailingMetadata(ServerMetadata& md) {
@@ -378,12 +370,11 @@ void ClientLoggingFilter::Call::OnServerTrailingMetadata(ServerMetadata& md) {
   if (md.get(GrpcCallWasCancelled()).value_or(false) &&
       md.get(GrpcStatusMetadata()) == GRPC_STATUS_CANCELLED) {
     call_data_->LogCancel(
-        /*is_client=*/true, MaybeGetContext<CallTracerAnnotationInterface>());
+        /*is_client=*/true, MaybeGetContext<CallSpan>());
     return;
   }
   call_data_->LogServerTrailer(
-      /*is_client=*/true, MaybeGetContext<CallTracerAnnotationInterface>(),
-      &md);
+      /*is_client=*/true, MaybeGetContext<CallSpan>(), &md);
 }
 
 void ClientLoggingFilter::Call::OnClientToServerMessage(
@@ -391,15 +382,14 @@ void ClientLoggingFilter::Call::OnClientToServerMessage(
   GRPC_LATENT_SEE_SCOPE("ClientLoggingFilter::Call::OnClientToServerMessage");
   if (!call_data_.has_value()) return;
   call_data_->LogClientMessage(
-      /*is_client=*/true, MaybeGetContext<CallTracerAnnotationInterface>(),
-      message.payload());
+      /*is_client=*/true, MaybeGetContext<CallSpan>(), message.payload());
 }
 
 void ClientLoggingFilter::Call::OnClientToServerHalfClose() {
   GRPC_LATENT_SEE_SCOPE("ClientLoggingFilter::Call::OnClientToServerHalfClose");
   if (!call_data_.has_value()) return;
   call_data_->LogClientHalfClose(
-      /*is_client=*/true, MaybeGetContext<CallTracerAnnotationInterface>());
+      /*is_client=*/true, MaybeGetContext<CallSpan>());
 }
 
 void ClientLoggingFilter::Call::OnServerToClientMessage(
@@ -407,8 +397,7 @@ void ClientLoggingFilter::Call::OnServerToClientMessage(
   GRPC_LATENT_SEE_SCOPE("ClientLoggingFilter::Call::OnServerToClientMessage");
   if (!call_data_.has_value()) return;
   call_data_->LogServerMessage(
-      /*is_client=*/true, MaybeGetContext<CallTracerAnnotationInterface>(),
-      message.payload());
+      /*is_client=*/true, MaybeGetContext<CallSpan>(), message.payload());
 }
 
 const grpc_channel_filter ClientLoggingFilter::kFilter =
@@ -432,16 +421,14 @@ void ServerLoggingFilter::Call::OnClientInitialMetadata(ClientMetadata& md) {
     return;
   }
   call_data_->LogClientHeader(
-      /*is_client=*/false, MaybeGetContext<CallTracerAnnotationInterface>(),
-      md);
+      /*is_client=*/false, MaybeGetContext<CallSpan>(), md);
 }
 
 void ServerLoggingFilter::Call::OnServerInitialMetadata(ServerMetadata& md) {
   GRPC_LATENT_SEE_SCOPE("ServerLoggingFilter::Call::OnServerInitialMetadata");
   if (!call_data_.has_value()) return;
   call_data_->LogServerHeader(
-      /*is_client=*/false, MaybeGetContext<CallTracerAnnotationInterface>(),
-      &md);
+      /*is_client=*/false, MaybeGetContext<CallSpan>(), &md);
 }
 
 void ServerLoggingFilter::Call::OnServerTrailingMetadata(ServerMetadata& md) {
@@ -450,12 +437,11 @@ void ServerLoggingFilter::Call::OnServerTrailingMetadata(ServerMetadata& md) {
   if (md.get(GrpcCallWasCancelled()).value_or(false) &&
       md.get(GrpcStatusMetadata()) == GRPC_STATUS_CANCELLED) {
     call_data_->LogCancel(
-        /*is_client=*/false, MaybeGetContext<CallTracerAnnotationInterface>());
+        /*is_client=*/false, MaybeGetContext<CallSpan>());
     return;
   }
   call_data_->LogServerTrailer(
-      /*is_client=*/false, MaybeGetContext<CallTracerAnnotationInterface>(),
-      &md);
+      /*is_client=*/false, MaybeGetContext<CallSpan>(), &md);
 }
 
 void ServerLoggingFilter::Call::OnClientToServerMessage(
@@ -463,15 +449,14 @@ void ServerLoggingFilter::Call::OnClientToServerMessage(
   GRPC_LATENT_SEE_SCOPE("ServerLoggingFilter::Call::OnClientToServerMessage");
   if (!call_data_.has_value()) return;
   call_data_->LogClientMessage(
-      /*is_client=*/false, MaybeGetContext<CallTracerAnnotationInterface>(),
-      message.payload());
+      /*is_client=*/false, MaybeGetContext<CallSpan>(), message.payload());
 }
 
 void ServerLoggingFilter::Call::OnClientToServerHalfClose() {
   GRPC_LATENT_SEE_SCOPE("ServerLoggingFilter::Call::OnClientToServerHalfClose");
   if (!call_data_.has_value()) return;
   call_data_->LogClientHalfClose(
-      /*is_client=*/false, MaybeGetContext<CallTracerAnnotationInterface>());
+      /*is_client=*/false, MaybeGetContext<CallSpan>());
 }
 
 void ServerLoggingFilter::Call::OnServerToClientMessage(
@@ -479,8 +464,7 @@ void ServerLoggingFilter::Call::OnServerToClientMessage(
   GRPC_LATENT_SEE_SCOPE("ServerLoggingFilter::Call::OnServerToClientMessage");
   if (!call_data_.has_value()) return;
   call_data_->LogServerMessage(
-      /*is_client=*/false, MaybeGetContext<CallTracerAnnotationInterface>(),
-      message.payload());
+      /*is_client=*/false, MaybeGetContext<CallSpan>(), message.payload());
 }
 
 const grpc_channel_filter ServerLoggingFilter::kFilter =
