@@ -24,12 +24,12 @@
 #include <tuple>
 
 #include "absl/cleanup/cleanup.h"
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/random/bit_gen_ref.h"
 #include "absl/random/random.h"
 #include "absl/status/status.h"
 #include "absl/status/statusor.h"
+#include "src/core/channelz/property_list.h"
 #include "src/core/ext/transport/chaotic_good/frame.h"
 #include "src/core/ext/transport/chaotic_good/frame_header.h"
 #include "src/core/ext/transport/chaotic_good/frame_transport.h"
@@ -47,6 +47,7 @@
 #include "src/core/lib/slice/slice.h"
 #include "src/core/lib/slice/slice_buffer.h"
 #include "src/core/lib/transport/promise_endpoint.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/ref_counted_ptr.h"
 
 namespace grpc_core {
@@ -97,7 +98,7 @@ void ChaoticGoodServerTransport::StreamDispatch::DispatchFrame(
   if (stream == nullptr) return;
   stream->spawn_serializer->Spawn(
       [this, stream, frame = std::move(frame)]() mutable {
-        DCHECK_NE(stream.get(), nullptr);
+        GRPC_DCHECK_NE(stream.get(), nullptr);
         auto& call = stream->call;
         return call.CancelIfFails(call.UntilCallCompletes(TrySeq(
             frame.Payload(),
@@ -110,33 +111,38 @@ void ChaoticGoodServerTransport::StreamDispatch::DispatchFrame(
 }
 
 auto ChaoticGoodServerTransport::StreamDispatch::SendCallBody(
-    uint32_t stream_id, CallInitiator call_initiator) {
+    uint32_t stream_id, CallInitiator call_initiator,
+    std::shared_ptr<TcpCallTracer> call_tracer) {
   // Continuously send client frame with client to server messages.
   return ForEach(MessagesFrom(call_initiator),
-                 [this, stream_id](MessageHandle message) mutable {
+                 [this, stream_id, call_tracer = std::move(call_tracer)](
+                     MessageHandle message) mutable {
                    return message_chunker_.Send(std::move(message), stream_id,
-                                                outgoing_frames_);
+                                                call_tracer, outgoing_frames_);
                  });
 }
 
 auto ChaoticGoodServerTransport::StreamDispatch::SendCallInitialMetadataAndBody(
-    uint32_t stream_id, CallInitiator call_initiator) {
+    uint32_t stream_id, CallInitiator call_initiator,
+    std::shared_ptr<TcpCallTracer> call_tracer) {
   return TrySeq(
       // Wait for initial metadata then send it out.
       call_initiator.PullServerInitialMetadata(),
-      [stream_id, call_initiator,
+      [stream_id, call_initiator, call_tracer = std::move(call_tracer),
        this](std::optional<ServerMetadataHandle> md) mutable {
         GRPC_TRACE_LOG(chaotic_good, INFO)
             << "CHAOTIC_GOOD: SendCallInitialMetadataAndBody: md="
             << (md.has_value() ? (*md)->DebugString() : "null");
         return If(
             md.has_value(),
-            [&md, stream_id, &call_initiator, this]() {
+            [&md, stream_id, &call_initiator, &call_tracer, this]() {
               ServerInitialMetadataFrame frame;
               frame.body = ServerMetadataProtoFromGrpc(**md);
               frame.stream_id = stream_id;
-              return TrySeq(outgoing_frames_.Send(std::move(frame)),
-                            SendCallBody(stream_id, call_initiator));
+              return TrySeq(
+                  outgoing_frames_.Send(
+                      OutgoingFrame{std::move(frame), call_tracer}, 1),
+                  SendCallBody(stream_id, call_initiator, call_tracer));
             },
             []() { return StatusFlag(true); });
       });
@@ -144,9 +150,15 @@ auto ChaoticGoodServerTransport::StreamDispatch::SendCallInitialMetadataAndBody(
 
 auto ChaoticGoodServerTransport::StreamDispatch::CallOutboundLoop(
     uint32_t stream_id, CallInitiator call_initiator) {
+  std::shared_ptr<TcpCallTracer> call_tracer;
+  auto tracer = call_initiator.arena()->GetContext<CallTracer>();
+  if (tracer != nullptr && tracer->IsSampled()) {
+    call_tracer = tracer->StartNewTcpTrace();
+  }
   return GRPC_LATENT_SEE_PROMISE(
       "CallOutboundLoop",
-      Seq(Map(SendCallInitialMetadataAndBody(stream_id, call_initiator),
+      Seq(Map(SendCallInitialMetadataAndBody(stream_id, call_initiator,
+                                             call_tracer),
               [stream_id](StatusFlag main_body_result) {
                 GRPC_TRACE_VLOG(chaotic_good, 2)
                     << "CHAOTIC_GOOD: CallOutboundLoop: stream_id=" << stream_id
@@ -154,12 +166,13 @@ auto ChaoticGoodServerTransport::StreamDispatch::CallOutboundLoop(
                 return Empty{};
               }),
           call_initiator.PullServerTrailingMetadata(),
-          [outgoing_frames = outgoing_frames_,
-           stream_id](ServerMetadataHandle md) mutable {
+          [outgoing_frames = outgoing_frames_, stream_id,
+           call_tracer](ServerMetadataHandle md) mutable {
             ServerTrailingMetadataFrame frame;
             frame.body = ServerMetadataProtoFromGrpc(*md);
             frame.stream_id = stream_id;
-            return outgoing_frames.Send(std::move(frame));
+            return outgoing_frames.Send(
+                OutgoingFrame{std::move(frame), call_tracer}, 1);
           }));
 }
 
@@ -172,7 +185,7 @@ absl::Status ChaoticGoodServerTransport::StreamDispatch::NewStream(
   }
   RefCountedPtr<Arena> arena(call_arena_allocator_->MakeArena());
   arena->SetContext<grpc_event_engine::experimental::EventEngine>(
-      event_engine_.get());
+      ctx_->event_engine.get());
   std::optional<CallInitiator> call_initiator;
   auto call = MakeCallPair(std::move(*md), std::move(arena));
   call_initiator.emplace(std::move(call.initiator));
@@ -256,8 +269,8 @@ ChaoticGoodServerTransport::StreamDispatch::StreamDispatch(
     const ChannelArgs& args, FrameTransport* frame_transport,
     MessageChunker message_chunker,
     RefCountedPtr<UnstartedCallDestination> call_destination)
-    : event_engine_(
-          args.GetObjectRef<grpc_event_engine::experimental::EventEngine>()),
+    : channelz::DataSource(frame_transport->ctx()->socket_node),
+      ctx_(frame_transport->ctx()),
       call_arena_allocator_(MakeRefCounted<CallArenaAllocator>(
           args.GetObject<ResourceQuota>()
               ->memory_quota()
@@ -265,14 +278,26 @@ ChaoticGoodServerTransport::StreamDispatch::StreamDispatch(
           1024)),
       call_destination_(std::move(call_destination)),
       message_chunker_(message_chunker) {
+  GRPC_CHECK(ctx_ != nullptr);
   auto party_arena = SimpleArenaAllocator(0)->MakeArena();
   party_arena->SetContext<grpc_event_engine::experimental::EventEngine>(
-      event_engine_.get());
+      ctx_->event_engine.get());
   party_ = Party::Make(std::move(party_arena));
   incoming_frame_spawner_ = party_->MakeSpawnSerializer();
-  MpscReceiver<Frame> outgoing_pipe(8);
+  MpscReceiver<OutgoingFrame> outgoing_pipe(256 * 1024 * 1024);
   outgoing_frames_ = outgoing_pipe.MakeSender();
   frame_transport->Start(party_.get(), std::move(outgoing_pipe), Ref());
+  SourceConstructed();
+}
+
+void ChaoticGoodServerTransport::StreamDispatch::AddData(
+    channelz::DataSink sink) {
+  party_->ExportToChannelz("transport_party", sink);
+  MutexLock lock(&mu_);
+  sink.AddData("transport_state",
+               channelz::PropertyList()
+                   .Set("stream_map_size", stream_map_.size())
+                   .Set("last_seen_new_stream_id", last_seen_new_stream_id_));
 }
 
 void ChaoticGoodServerTransport::SetCallDestination(
@@ -295,7 +320,9 @@ void ChaoticGoodServerTransport::Orphan() {
 }
 
 void ChaoticGoodServerTransport::StreamDispatch::OnFrameTransportClosed(
-    absl::Status) {
+    absl::Status status) {
+  GRPC_TRACE_LOG(chaotic_good, INFO)
+      << "CHAOTIC_GOOD: OnFrameTransportClosed: " << status;
   // Mark transport as unavailable when the endpoint write/read failed.
   // Close all the available pipes.
   ReleasableMutexLock lock(&mu_);
