@@ -17,14 +17,14 @@
 #include <grpc/support/port_platform.h>
 #include <grpcpp/security/credentials.h>
 
-#include "absl/log/check.h"
 #include "absl/strings/str_cat.h"
+#include "src/core/util/grpc_check.h"
 
 namespace grpc {
 
 CallCredentials::CallCredentials(grpc_call_credentials* c_creds)
     : c_creds_(c_creds) {
-  CHECK_NE(c_creds, nullptr);
+  GRPC_CHECK_NE(c_creds, nullptr);
 }
 
 CallCredentials::~CallCredentials() { grpc_call_credentials_release(c_creds_); }
