@@ -35,7 +35,6 @@
 #include <utility>
 #include <vector>
 
-#include "absl/log/check.h"
 #include "absl/status/status.h"
 #include "absl/strings/str_cat.h"
 #include "absl/strings/str_format.h"
@@ -59,6 +58,7 @@
 #include "src/core/lib/surface/call.h"
 #include "src/core/lib/transport/transport.h"
 #include "src/core/telemetry/tcp_tracer.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/sync.h"
 #include "src/cpp/ext/filters/census/context.h"
 #include "src/cpp/ext/filters/census/grpc_plugin.h"
@@ -101,9 +101,9 @@ OpenCensusClientFilter::MakeCallPromise(
       path != nullptr ? path->Ref() : grpc_core::Slice(),
       grpc_core::GetContext<grpc_core::Arena>(),
       OpenCensusTracingEnabled() && tracing_enabled_);
-  DCHECK_EQ(arena->GetContext<grpc_core::CallTracerAnnotationInterface>(),
-            nullptr);
-  grpc_core::SetContext<grpc_core::CallTracerAnnotationInterface>(tracer);
+  GRPC_DCHECK_EQ(arena->GetContext<grpc_core::CallSpan>(), nullptr);
+  grpc_core::SetContext<grpc_core::CallSpan>(
+      grpc_core::WrapClientCallTracer(tracer, arena));
   return next_promise_factory(std::move(call_args));
 }
 
@@ -411,7 +411,7 @@ void OpenCensusCallTracer::RecordApiLatency(absl::Duration api_latency,
 
 CensusContext OpenCensusCallTracer::CreateCensusContextForCallAttempt() {
   if (!tracing_enabled_) return CensusContext(context_.tags());
-  DCHECK(context_.Context().IsValid());
+  GRPC_DCHECK(context_.Context().IsValid());
   auto context = CensusContext(absl::StrCat("Attempt.", method_),
                                &(context_.Span()), context_.tags());
   grpc::internal::OpenCensusRegistry::Get()
@@ -430,7 +430,8 @@ class OpenCensusClientInterceptor : public grpc::experimental::Interceptor {
             grpc::experimental::InterceptionHookPoints::POST_RECV_STATUS)) {
       auto* tracer = grpc_core::DownCast<OpenCensusCallTracer*>(
           grpc_call_get_arena(info_->client_context()->c_call())
-              ->GetContext<grpc_core::CallTracerAnnotationInterface>());
+              ->GetContext<grpc_core::CallSpan>()
+              ->span_impl());
       if (tracer != nullptr) {
         tracer->RecordApiLatency(absl::Now() - start_time_,
                                  static_cast<absl::StatusCode>(
