@@ -25,13 +25,13 @@
 #include <optional>
 #include <utility>
 
-#include "absl/log/check.h"
 #include "absl/strings/string_view.h"
 #include "absl/types/span.h"
 #include "opentelemetry/common/attribute_value.h"
 #include "opentelemetry/common/key_value_iterable.h"
 #include "opentelemetry/nostd/function_ref.h"
 #include "opentelemetry/nostd/string_view.h"
+#include "src/core/util/grpc_check.h"
 #include "src/cpp/ext/otel/otel_plugin.h"
 
 namespace grpc {
@@ -100,7 +100,7 @@ class OpenTelemetryPluginImpl::KeyValueIterable
     }
     // Add per-call optional labels
     if (!optional_labels_.empty()) {
-      CHECK(
+      GRPC_CHECK(
           optional_labels_.size() ==
           static_cast<size_t>(grpc_core::ClientCallTracerInterface::
                                   CallAttemptTracer::OptionalLabelKey::kSize));
