@@ -23,12 +23,12 @@
 #include <list>
 
 #include "absl/base/no_destructor.h"
-#include "absl/log/check.h"
 #include "absl/status/status.h"
 #include "gmock/gmock.h"
 #include "gtest/gtest.h"
 #include "src/core/lib/slice/slice_internal.h"
 #include "src/core/util/crash.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/match.h"
 #include "src/core/util/tmpfile.h"
 #include "test/core/test_util/test_config.h"
@@ -195,7 +195,7 @@ class GrpcTlsCertificateProviderTest : public ::testing::Test {
     void OnError(grpc_error_handle root_cert_error,
                  grpc_error_handle identity_cert_error) override {
       MutexLock lock(&state_->mu);
-      CHECK(!root_cert_error.ok() || !identity_cert_error.ok());
+      GRPC_CHECK(!root_cert_error.ok() || !identity_cert_error.ok());
       std::string root_error_str;
       if (!root_cert_error.ok()) {
         root_error_str = std::string(root_cert_error.message());
