@@ -31,12 +31,12 @@
 
 #include <string>
 
-#include "absl/log/check.h"
 #include "absl/strings/string_view.h"
 #include "src/core/credentials/transport/tls/grpc_tls_credentials_options.h"
 #include "src/core/lib/channel/channel_args.h"
 #include "src/core/lib/iomgr/error.h"
 #include "src/core/lib/slice/slice_internal.h"
+#include "src/core/util/grpc_check.h"
 #include "test/core/end2end/end2end_tests.h"
 #include "test/core/end2end/fixtures/secure_fixture.h"
 #include "test/core/test_util/tls_utils.h"
@@ -61,7 +61,7 @@ inline void process_auth_failure(void* state, grpc_auth_context* /*ctx*/,
                                  size_t /*md_count*/,
                                  grpc_process_auth_metadata_done_cb cb,
                                  void* user_data) {
-  CHECK_EQ(state, nullptr);
+  GRPC_CHECK_EQ(state, nullptr);
   cb(user_data, nullptr, 0, nullptr, 0, GRPC_STATUS_UNAUTHENTICATED, nullptr);
 }
 
@@ -104,9 +104,11 @@ class TlsFixture : public SecureFixture {
       }
       case SecurityPrimitives::ProviderType::FILE_PROVIDER: {
         client_provider_ = grpc_tls_certificate_provider_file_watcher_create(
-            SERVER_KEY_PATH, SERVER_CERT_PATH, CA_CERT_PATH, 1);
+            SERVER_KEY_PATH, SERVER_CERT_PATH, CA_CERT_PATH,
+            /*spiffe_bundle_map_path=*/"", 1);
         server_provider_ = grpc_tls_certificate_provider_file_watcher_create(
-            SERVER_KEY_PATH, SERVER_CERT_PATH, CA_CERT_PATH, 1);
+            SERVER_KEY_PATH, SERVER_CERT_PATH, CA_CERT_PATH,
+            /*spiffe_bundle_map_path=*/"", 1);
         break;
       }
     }
