@@ -32,8 +32,8 @@
 #include <memory>
 #include <string>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/host_port.h"
 #include "test/core/end2end/cq_verifier.h"
 #include "test/core/test_util/port.h"
@@ -108,15 +108,16 @@ static void prepare_test(int is_client) {
     op->flags = GRPC_INITIAL_METADATA_WAIT_FOR_READY;
     op->reserved = nullptr;
     op++;
-    CHECK_EQ(GRPC_CALL_OK,
-             grpc_call_start_batch(g_state.call, g_state.ops,
-                                   (size_t)(op - g_state.ops),
-                                   grpc_core::CqVerifier::tag(1), nullptr));
-    CHECK_EQ(GRPC_CALL_OK,
-             grpc_server_request_call(
-                 g_state.server, &g_state.server_call, &g_state.call_details,
-                 &g_state.server_initial_metadata_recv, g_state.cq, g_state.cq,
-                 grpc_core::CqVerifier::tag(101)));
+    GRPC_CHECK_EQ(GRPC_CALL_OK,
+                  grpc_call_start_batch(
+                      g_state.call, g_state.ops, (size_t)(op - g_state.ops),
+                      grpc_core::CqVerifier::tag(1), nullptr));
+    GRPC_CHECK_EQ(
+        GRPC_CALL_OK,
+        grpc_server_request_call(
+            g_state.server, &g_state.server_call, &g_state.call_details,
+            &g_state.server_initial_metadata_recv, g_state.cq, g_state.cq,
+            grpc_core::CqVerifier::tag(101)));
     g_state.cqv->Expect(grpc_core::CqVerifier::tag(101), true);
     g_state.cqv->Expect(grpc_core::CqVerifier::tag(1), true);
     g_state.cqv->Verify();
@@ -156,9 +157,9 @@ static void test_non_null_reserved_on_start_batch() {
   LOG(INFO) << "test_non_null_reserved_on_start_batch";
 
   prepare_test(1);
-  CHECK(GRPC_CALL_ERROR ==
-        grpc_call_start_batch(g_state.call, nullptr, 0, nullptr,
-                              grpc_core::CqVerifier::tag(1)));
+  GRPC_CHECK(GRPC_CALL_ERROR ==
+             grpc_call_start_batch(g_state.call, nullptr, 0, nullptr,
+                                   grpc_core::CqVerifier::tag(1)));
   cleanup_test();
 }
 
@@ -174,10 +175,10 @@ static void test_non_null_reserved_on_op() {
   op->flags = 0;
   op->reserved = grpc_core::CqVerifier::tag(2);
   op++;
-  CHECK(GRPC_CALL_ERROR == grpc_call_start_batch(g_state.call, g_state.ops,
-                                                 (size_t)(op - g_state.ops),
-                                                 grpc_core::CqVerifier::tag(1),
-                                                 nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR ==
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
@@ -193,10 +194,10 @@ static void test_send_initial_metadata_more_than_once() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK_EQ(GRPC_CALL_OK,
-           grpc_call_start_batch(g_state.call, g_state.ops,
-                                 (size_t)(op - g_state.ops),
-                                 grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK_EQ(GRPC_CALL_OK,
+                grpc_call_start_batch(g_state.call, g_state.ops,
+                                      (size_t)(op - g_state.ops),
+                                      grpc_core::CqVerifier::tag(1), nullptr));
   g_state.cqv->Expect(grpc_core::CqVerifier::tag(1), false);
   g_state.cqv->Verify();
 
@@ -206,10 +207,10 @@ static void test_send_initial_metadata_more_than_once() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-        grpc_call_start_batch(g_state.call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
@@ -225,10 +226,10 @@ static void test_too_many_metadata() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_INVALID_METADATA ==
-        grpc_call_start_batch(g_state.call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_INVALID_METADATA ==
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
@@ -249,10 +250,10 @@ static void test_send_null_message() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_INVALID_MESSAGE ==
-        grpc_call_start_batch(g_state.call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_INVALID_MESSAGE ==
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
@@ -282,10 +283,10 @@ static void test_send_messages_at_the_same_time() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-        grpc_call_start_batch(g_state.call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
   grpc_byte_buffer_destroy(request_payload);
   cleanup_test();
 }
@@ -305,10 +306,10 @@ static void test_send_server_status_from_client() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_NOT_ON_CLIENT ==
-        grpc_call_start_batch(g_state.call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_NOT_ON_CLIENT ==
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
@@ -324,10 +325,10 @@ static void test_receive_initial_metadata_twice_at_client() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK_EQ(GRPC_CALL_OK,
-           grpc_call_start_batch(g_state.call, g_state.ops,
-                                 (size_t)(op - g_state.ops),
-                                 grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK_EQ(GRPC_CALL_OK,
+                grpc_call_start_batch(g_state.call, g_state.ops,
+                                      (size_t)(op - g_state.ops),
+                                      grpc_core::CqVerifier::tag(1), nullptr));
   g_state.cqv->Expect(grpc_core::CqVerifier::tag(1), false);
   g_state.cqv->Verify();
   op = g_state.ops;
@@ -337,10 +338,10 @@ static void test_receive_initial_metadata_twice_at_client() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-        grpc_call_start_batch(g_state.call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
@@ -356,10 +357,10 @@ static void test_receive_message_with_invalid_flags() {
   op->flags = 1;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_INVALID_FLAGS ==
-        grpc_call_start_batch(g_state.call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_INVALID_FLAGS ==
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
@@ -380,10 +381,10 @@ static void test_receive_two_messages_at_the_same_time() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-        grpc_call_start_batch(g_state.call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
@@ -399,10 +400,10 @@ static void test_recv_close_on_server_from_client() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_NOT_ON_CLIENT ==
-        grpc_call_start_batch(g_state.call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_NOT_ON_CLIENT ==
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
@@ -421,10 +422,10 @@ static void test_recv_status_on_client_twice() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK_EQ(GRPC_CALL_OK,
-           grpc_call_start_batch(g_state.call, g_state.ops,
-                                 (size_t)(op - g_state.ops),
-                                 grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK_EQ(GRPC_CALL_OK,
+                grpc_call_start_batch(g_state.call, g_state.ops,
+                                      (size_t)(op - g_state.ops),
+                                      grpc_core::CqVerifier::tag(1), nullptr));
   g_state.cqv->Expect(grpc_core::CqVerifier::tag(1), true);
   g_state.cqv->Verify();
 
@@ -436,10 +437,10 @@ static void test_recv_status_on_client_twice() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-        grpc_call_start_batch(g_state.call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
@@ -454,10 +455,10 @@ static void test_send_close_from_client_on_server() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_NOT_ON_SERVER ==
-        grpc_call_start_batch(g_state.server_call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(2), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_NOT_ON_SERVER ==
+             grpc_call_start_batch(g_state.server_call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
@@ -476,10 +477,10 @@ static void test_recv_status_on_client_from_server() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_NOT_ON_SERVER ==
-        grpc_call_start_batch(g_state.server_call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(2), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_NOT_ON_SERVER ==
+             grpc_call_start_batch(g_state.server_call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
@@ -498,10 +499,10 @@ static void test_send_status_from_server_with_invalid_flags() {
   op->flags = 1;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_INVALID_FLAGS ==
-        grpc_call_start_batch(g_state.server_call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(2), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_INVALID_FLAGS ==
+             grpc_call_start_batch(g_state.server_call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
@@ -521,10 +522,10 @@ static void test_too_many_trailing_metadata() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_INVALID_METADATA ==
-        grpc_call_start_batch(g_state.server_call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(2), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_INVALID_METADATA ==
+             grpc_call_start_batch(g_state.server_call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
@@ -550,10 +551,10 @@ static void test_send_server_status_twice() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-        grpc_call_start_batch(g_state.server_call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(2), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+             grpc_call_start_batch(g_state.server_call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
@@ -569,10 +570,10 @@ static void test_recv_close_on_server_with_invalid_flags() {
   op->flags = 1;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_INVALID_FLAGS ==
-        grpc_call_start_batch(g_state.server_call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(2), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_INVALID_FLAGS ==
+             grpc_call_start_batch(g_state.server_call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
@@ -593,10 +594,10 @@ static void test_recv_close_on_server_twice() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-        grpc_call_start_batch(g_state.server_call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(2), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+             grpc_call_start_batch(g_state.server_call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(2), nullptr));
   cleanup_test();
 }
 
@@ -616,10 +617,10 @@ static void test_invalid_initial_metadata_reserved_key() {
   op->flags = 0;
   op->reserved = nullptr;
   op++;
-  CHECK(GRPC_CALL_ERROR_INVALID_METADATA ==
-        grpc_call_start_batch(g_state.call, g_state.ops,
-                              (size_t)(op - g_state.ops),
-                              grpc_core::CqVerifier::tag(1), nullptr));
+  GRPC_CHECK(GRPC_CALL_ERROR_INVALID_METADATA ==
+             grpc_call_start_batch(g_state.call, g_state.ops,
+                                   (size_t)(op - g_state.ops),
+                                   grpc_core::CqVerifier::tag(1), nullptr));
   cleanup_test();
 }
 
@@ -639,10 +640,10 @@ static void test_multiple_ops_in_a_single_batch() {
     op++;
     op->op = which;
     op++;
-    CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
-          grpc_call_start_batch(g_state.call, g_state.ops,
-                                (size_t)(op - g_state.ops),
-                                grpc_core::CqVerifier::tag(1), nullptr));
+    GRPC_CHECK(GRPC_CALL_ERROR_TOO_MANY_OPERATIONS ==
+               grpc_call_start_batch(g_state.call, g_state.ops,
+                                     (size_t)(op - g_state.ops),
+                                     grpc_core::CqVerifier::tag(1), nullptr));
   }
 
   cleanup_test();
