@@ -26,7 +26,6 @@
 #include <string>
 #include <utility>
 
-#include "absl/log/check.h"
 #include "absl/log/globals.h"
 #include "absl/log/log.h"
 #include "absl/log/log_entry.h"
@@ -36,6 +35,7 @@
 #include "absl/strings/string_view.h"
 #include "gtest/gtest.h"
 #include "src/core/lib/debug/trace.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/time.h"
 #include "test/core/end2end/end2end_tests.h"
 
@@ -55,7 +55,7 @@ class VerifyLogNoiseLogSink : public absl::LogSink {
   }
 
   ~VerifyLogNoiseLogSink() override {
-    CHECK(log_noise_absent_)
+    GRPC_CHECK(log_noise_absent_)
         << "Unwanted logs present. This will cause log noise. Either user a "
            "tracer (example GRPC_TRACE_LOG or GRPC_TRACE_VLOG) or convert the "
            "statement to VLOG(2).";
