@@ -21,7 +21,6 @@
 
 #include <thread>
 
-#include "absl/log/check.h"
 #include "absl/status/status.h"
 #include "absl/strings/str_format.h"
 #include "gmock/gmock.h"
@@ -31,6 +30,7 @@
 #include "src/core/lib/event_engine/tcp_socket_utils.h"
 #include "src/core/lib/resource_quota/memory_quota.h"
 #include "src/core/lib/resource_quota/resource_quota.h"
+#include "src/core/util/grpc_check.h"
 #include "test/core/test_util/port.h"
 
 using namespace std::chrono_literals;
@@ -41,9 +41,11 @@ namespace experimental {
 TEST(CFEventEngineTest, TestConnectionTimeout) {
   // use a non-routable IP so connection will timeout
   auto resolved_addr = URIToResolvedAddress("ipv4:8.8.8.8:1234");
-  CHECK_OK(resolved_addr);
+  GRPC_CHECK_OK(resolved_addr);
 
-  grpc_core::MemoryQuota memory_quota("cf_engine_test");
+  grpc_core::MemoryQuota memory_quota(
+      grpc_core::MakeRefCounted<grpc_core::channelz::ResourceQuotaNode>(
+          "cf_engine_test"));
   grpc_core::Notification client_signal;
   auto cf_engine = std::make_shared<CFEventEngine>();
 
@@ -64,9 +66,11 @@ TEST(CFEventEngineTest, TestConnectionTimeout) {
 TEST(CFEventEngineTest, TestConnectionCancelled) {
   // use a non-routable IP so to cancel connection before timeout
   auto resolved_addr = URIToResolvedAddress("ipv4:8.8.8.8:1234");
-  CHECK_OK(resolved_addr);
+  GRPC_CHECK_OK(resolved_addr);
 
-  grpc_core::MemoryQuota memory_quota("cf_engine_test");
+  grpc_core::MemoryQuota memory_quota(
+      grpc_core::MakeRefCounted<grpc_core::channelz::ResourceQuotaNode>(
+          "cf_engine_test"));
   grpc_core::Notification client_signal;
   auto cf_engine = std::make_shared<CFEventEngine>();
 
@@ -97,7 +101,9 @@ std::vector<std::string> ResolvedAddressesToStrings(
 }  // namespace
 
 TEST(CFEventEngineTest, TestCreateDNSResolver) {
-  grpc_core::MemoryQuota memory_quota("cf_engine_test");
+  grpc_core::MemoryQuota memory_quota(
+      grpc_core::MakeRefCounted<grpc_core::channelz::ResourceQuotaNode>(
+          "cf_engine_test"));
   auto cf_engine = std::make_shared<CFEventEngine>();
 
   EXPECT_TRUE(cf_engine->GetDNSResolver({}).status().ok());
