@@ -66,12 +66,8 @@ class ExtendedTestEndpoint
   const EventEngine::ResolvedAddress& GetLocalAddress() const override {
     grpc_core::Crash("Not implemented");
   };
-  std::vector<size_t> AllWriteMetrics() override { return {}; }
-  std::optional<absl::string_view> GetMetricName(size_t) override {
-    return std::nullopt;
-  }
-  std::optional<size_t> GetMetricKey(absl::string_view) override {
-    return std::nullopt;
+  std::shared_ptr<TelemetryInfo> GetTelemetryInfo() const override {
+    return nullptr;
   }
 };
 
