@@ -66,6 +66,15 @@ class GcpAuthenticationFilterTest : public FilterTest<GcpAuthenticationFilter> {
     return xds_config;
   }
 
+  static RefCountedPtr<Blackboard> MakeBlackboard(
+      absl::string_view filter_instance_name) {
+    auto blackboard = MakeRefCounted<Blackboard>();
+    auto cache =
+        MakeRefCounted<GcpAuthenticationFilter::CallCredentialsCache>(10);
+    blackboard->Set(std::string(filter_instance_name), std::move(cache));
+    return blackboard;
+  }
+
   static RefCountedPtr<const XdsConfig> MakeXdsConfigWithCluster(
       absl::string_view cluster,
       absl::StatusOr<XdsConfig::ClusterConfig> cluster_config) {
@@ -105,8 +114,9 @@ TEST_F(GcpAuthenticationFilterTest, CreateSucceeds) {
       "}";
   auto channel_args = MakeChannelArgs(kServiceConfigJson, kClusterName,
                                       kFilterInstanceName, nullptr);
+  auto blackboard = MakeBlackboard(kFilterInstanceName);
   auto filter = GcpAuthenticationFilter::Create(
-      channel_args, ChannelFilter::Args(/*instance_id=*/0));
+      channel_args, ChannelFilter::Args(/*instance_id=*/0, blackboard.get()));
   EXPECT_TRUE(filter.ok()) << filter.status();
 }
 
@@ -163,7 +173,8 @@ TEST_F(GcpAuthenticationFilterTest, FailsCallIfNoXdsClusterAttribute) {
       "}";
   auto channel_args = MakeChannelArgs(kServiceConfigJson, kClusterName,
                                       kFilterInstanceName, nullptr);
-  Call call(MakeChannel(channel_args).value());
+  auto blackboard = MakeBlackboard(kFilterInstanceName);
+  Call call(MakeChannel(channel_args, blackboard.get()).value());
   call.arena()->New<ServiceConfigCallData>(call.arena());
   call.Start(call.NewClientMetadata());
   EXPECT_EVENT(Finished(
@@ -188,7 +199,8 @@ TEST_F(GcpAuthenticationFilterTest, NoOpIfClusterAttributeHasWrongPrefix) {
   auto channel_args = MakeChannelArgs(
       kServiceConfigJson, kClusterName, kFilterInstanceName,
       std::make_unique<XdsGcpAuthnAudienceMetadataValue>(kAudience));
-  Call call(MakeChannel(channel_args).value());
+  auto blackboard = MakeBlackboard(kFilterInstanceName);
+  Call call(MakeChannel(channel_args, blackboard.get()).value());
   auto* service_config_call_data =
       call.arena()->New<ServiceConfigCallData>(call.arena());
   XdsClusterAttribute xds_cluster_attribute(kClusterName);
@@ -212,7 +224,8 @@ TEST_F(GcpAuthenticationFilterTest, FailsCallIfClusterNotPresentInXdsConfig) {
       "}";
   auto channel_args = MakeChannelArgs(kServiceConfigJson, /*cluster=*/"",
                                       /*filter_instance_name=*/"", nullptr);
-  Call call(MakeChannel(channel_args).value());
+  auto blackboard = MakeBlackboard("gcp_authn_filter");
+  Call call(MakeChannel(channel_args, blackboard.get()).value());
   auto* service_config_call_data =
       call.arena()->New<ServiceConfigCallData>(call.arena());
   std::string cluster_name_with_prefix = absl::StrCat("cluster:", kClusterName);
@@ -240,7 +253,8 @@ TEST_F(GcpAuthenticationFilterTest, FailsCallIfClusterNotOkayInXdsConfig) {
                           .SetObject(MakeServiceConfig(kServiceConfigJson))
                           .SetObject(MakeXdsConfigWithCluster(
                               kClusterName, absl::UnavailableError("nope")));
-  Call call(MakeChannel(channel_args).value());
+  auto blackboard = MakeBlackboard("gcp_authn_filter");
+  Call call(MakeChannel(channel_args, blackboard.get()).value());
   auto* service_config_call_data =
       call.arena()->New<ServiceConfigCallData>(call.arena());
   std::string cluster_name_with_prefix = absl::StrCat("cluster:", kClusterName);
@@ -270,7 +284,8 @@ TEST_F(GcpAuthenticationFilterTest,
           .SetObject(MakeServiceConfig(kServiceConfigJson))
           .SetObject(MakeXdsConfigWithCluster(
               kClusterName, XdsConfig::ClusterConfig(nullptr, nullptr, "")));
-  Call call(MakeChannel(channel_args).value());
+  auto blackboard = MakeBlackboard("gcp_authn_filter");
+  Call call(MakeChannel(channel_args, blackboard.get()).value());
   auto* service_config_call_data =
       call.arena()->New<ServiceConfigCallData>(call.arena());
   std::string cluster_name_with_prefix = absl::StrCat("cluster:", kClusterName);
@@ -298,7 +313,8 @@ TEST_F(GcpAuthenticationFilterTest, NoOpIfClusterHasNoAudience) {
       "}";
   auto channel_args = MakeChannelArgs(kServiceConfigJson, kClusterName,
                                       kFilterInstanceName, nullptr);
-  Call call(MakeChannel(channel_args).value());
+  auto blackboard = MakeBlackboard(kFilterInstanceName);
+  Call call(MakeChannel(channel_args, blackboard.get()).value());
   auto* service_config_call_data =
       call.arena()->New<ServiceConfigCallData>(call.arena());
   std::string cluster_name_with_prefix = absl::StrCat("cluster:", kClusterName);
@@ -325,7 +341,8 @@ TEST_F(GcpAuthenticationFilterTest, FailsCallIfAudienceMetadataWrongType) {
   auto channel_args =
       MakeChannelArgs(kServiceConfigJson, kClusterName, kFilterInstanceName,
                       std::make_unique<XdsStructMetadataValue>(Json()));
-  Call call(MakeChannel(channel_args).value());
+  auto blackboard = MakeBlackboard(kFilterInstanceName);
+  Call call(MakeChannel(channel_args, blackboard.get()).value());
   auto* service_config_call_data =
       call.arena()->New<ServiceConfigCallData>(call.arena());
   std::string cluster_name_with_prefix = absl::StrCat("cluster:", kClusterName);
@@ -355,7 +372,8 @@ TEST_F(GcpAuthenticationFilterTest, SetsCallCredsIfClusterHasAudience) {
   auto channel_args = MakeChannelArgs(
       kServiceConfigJson, kClusterName, kFilterInstanceName,
       std::make_unique<XdsGcpAuthnAudienceMetadataValue>(kAudience));
-  Call call(MakeChannel(channel_args).value());
+  auto blackboard = MakeBlackboard(kFilterInstanceName);
+  Call call(MakeChannel(channel_args, blackboard.get()).value());
   auto* service_config_call_data =
       call.arena()->New<ServiceConfigCallData>(call.arena());
   std::string cluster_name_with_prefix = absl::StrCat("cluster:", kClusterName);
