@@ -39,6 +39,7 @@
 #include "src/core/lib/resource_quota/arena.h"
 #include "src/core/lib/resource_quota/memory_quota.h"
 #include "src/core/lib/resource_quota/resource_quota.h"
+#include "src/core/util/json/json_writer.h"
 #include "src/core/util/notification.h"
 #include "src/core/util/ref_counted_ptr.h"
 #include "src/core/util/sync.h"
@@ -1178,6 +1179,19 @@ TEST_F(PartyTest, SpawnSerializerSerializes) {
   thd.join();
 }
 
+TEST_F(PartyTest, SimpleJson) {
+  auto party = MakeParty();
+  Notification notification;
+  party->ToJson([&](Json::Object json) {
+    LOG(INFO) << "json: " << JsonDump(Json::FromObject(json));
+    int refs;
+    ASSERT_TRUE(absl::SimpleAtoi(json["ref_count"].string(), &refs));
+    EXPECT_GE(refs, 1);
+    notification.Notify();
+  });
+  notification.WaitForNotification();
+}
+
 }  // namespace grpc_core
 
 int main(int argc, char** argv) {
