@@ -16,7 +16,7 @@
 #define GRPC_TEST_CORE_TEST_UTIL_POSTMORTEM_H
 
 #include "gtest/gtest.h"
-#include "test/core/test_util/postmortem_emit.h"
+#include "src/core/util/postmortem_emit.h"
 
 namespace grpc_core {
 
