@@ -51,23 +51,6 @@ TEST(PingRatePolicy, ServerCanSendAtStart) {
             SendGranted());
 }
 
-TEST(PingRatePolicy, ClientBlockedUntilDataSent) {
-  if (IsMaxPingsWoDataThrottleEnabled()) {
-    GTEST_SKIP()
-        << "Pings are not blocked if max_pings_wo_data_throttle is enabled.";
-  }
-  Chttp2PingRatePolicy policy{ChannelArgs(), true};
-  EXPECT_EQ(policy.RequestSendPing(Duration::Milliseconds(10), 0),
-            TooManyRecentPings());
-  policy.ResetPingsBeforeDataRequired();
-  EXPECT_EQ(policy.RequestSendPing(Duration::Milliseconds(10), 0),
-            SendGranted());
-  policy.SentPing();
-  EXPECT_EQ(policy.RequestSendPing(Duration::Zero(), 0), SendGranted());
-  policy.SentPing();
-  EXPECT_EQ(policy.RequestSendPing(Duration::Zero(), 0), TooManyRecentPings());
-}
-
 MATCHER_P2(IsWithinRange, lo, hi,
            absl::StrCat(negation ? "isn't" : "is", " between ",
                         PrintToString(lo), " and ", PrintToString(hi))) {
@@ -75,10 +58,6 @@ MATCHER_P2(IsWithinRange, lo, hi,
 }
 
 TEST(PingRatePolicy, ClientThrottledUntilDataSent) {
-  if (!IsMaxPingsWoDataThrottleEnabled()) {
-    GTEST_SKIP()
-        << "Throttling behavior is enabled with max_pings_wo_data_throttle.";
-  }
   Chttp2PingRatePolicy policy{ChannelArgs(), true};
   // First ping is allowed.
   EXPECT_EQ(policy.RequestSendPing(Duration::Milliseconds(10), 0),
