@@ -17,7 +17,6 @@
 //
 
 #include <fcntl.h>
-#include <gmock/gmock.h>
 #include <grpc/credentials.h>
 #include <grpc/grpc.h>
 #include <grpc/grpc_security.h>
@@ -40,16 +39,17 @@
 #include <set>
 #include <thread>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/memory/memory.h"
 #include "absl/strings/str_cat.h"
+#include "gmock/gmock.h"
+#include "src/core/credentials/transport/alts/alts_credentials.h"
+#include "src/core/credentials/transport/alts/alts_security_connector.h"
+#include "src/core/credentials/transport/transport_credentials.h"
 #include "src/core/lib/iomgr/error.h"
-#include "src/core/lib/security/credentials/alts/alts_credentials.h"
-#include "src/core/lib/security/credentials/credentials.h"
-#include "src/core/lib/security/security_connector/alts/alts_security_connector.h"
 #include "src/core/lib/slice/slice_string_helpers.h"
 #include "src/core/util/crash.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/host_port.h"
 #include "src/core/util/thd.h"
 #include "src/core/util/useful.h"
@@ -141,8 +141,8 @@ class TestServer {
     grpc_server_register_completion_queue(server_, server_cq_, nullptr);
     int port = grpc_pick_unused_port_or_die();
     server_addr_ = grpc_core::JoinHostPort("localhost", port);
-    CHECK(grpc_server_add_http2_port(server_, server_addr_.c_str(),
-                                     server_creds));
+    GRPC_CHECK(grpc_server_add_http2_port(server_, server_addr_.c_str(),
+                                          server_creds));
     grpc_server_credentials_release(server_creds);
     grpc_server_start(server_);
     VLOG(2) << "Start TestServer " << this << ". listen on " << server_addr_;
@@ -164,8 +164,8 @@ class TestServer {
   static void PollUntilShutdown(const TestServer* self) {
     grpc_event ev = grpc_completion_queue_next(
         self->server_cq_, gpr_inf_future(GPR_CLOCK_REALTIME), nullptr);
-    CHECK(ev.type == GRPC_OP_COMPLETE);
-    CHECK(ev.tag == self);
+    GRPC_CHECK(ev.type == GRPC_OP_COMPLETE);
+    GRPC_CHECK(ev.tag == self);
     VLOG(2) << "TestServer " << self << " stop polling";
   }
 
