@@ -20,13 +20,13 @@
 #include <stdint.h>
 #include <string.h>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/status/statusor.h"
 #include "absl/strings/string_view.h"
 #include "fuzztest/fuzztest.h"
 #include "gtest/gtest.h"
 #include "src/core/util/dump_args.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/json/json_reader.h"
 #include "src/core/util/json/json_writer.h"
 
@@ -38,7 +38,7 @@ void ParseRoundTrips(std::string input) {
   if (json.ok()) {
     auto text2 = JsonDump(*json);
     auto json2 = JsonParse(text2);
-    CHECK_OK(json2);
+    GRPC_CHECK_OK(json2);
     EXPECT_EQ(*json, *json2)
         << GRPC_DUMP_ARGS(absl::CEscape(input), absl::CEscape(text2));
   }
