@@ -26,9 +26,9 @@
 #include <type_traits>
 #include <utility>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
+#include "src/core/util/grpc_check.h"
 #include "src/core/util/orphanable.h"
 #include "src/core/util/ref_counted_ptr.h"
 #include "src/core/xds/xds_client/xds_bootstrap.h"
@@ -49,7 +49,7 @@ FakeXdsTransportFactory::FakeStreamingCall::~FakeStreamingCall() {
         LOG(ERROR) << "[" << transport_->server()->server_uri() << "] " << this
                    << " From client message left in queue: " << message;
       }
-      CHECK(from_client_messages_.empty());
+      GRPC_CHECK(from_client_messages_.empty());
     }
   }
   // Can't call event_handler_->OnStatusReceived() or unref event_handler_
@@ -76,7 +76,7 @@ void FakeXdsTransportFactory::FakeStreamingCall::Orphan() {
 void FakeXdsTransportFactory::FakeStreamingCall::SendMessage(
     std::string payload) {
   MutexLock lock(&mu_);
-  CHECK(!orphaned_);
+  GRPC_CHECK(!orphaned_);
   from_client_messages_.push_back(std::move(payload));
   if (transport_->auto_complete_messages_from_client()) {
     CompleteSendMessageFromClientLocked(/*ok=*/true);
@@ -118,7 +118,7 @@ void FakeXdsTransportFactory::FakeStreamingCall::
 
 void FakeXdsTransportFactory::FakeStreamingCall::CompleteSendMessageFromClient(
     bool ok) {
-  CHECK(!transport_->auto_complete_messages_from_client());
+  GRPC_CHECK(!transport_->auto_complete_messages_from_client());
   MutexLock lock(&mu_);
   CompleteSendMessageFromClientLocked(ok);
 }
