@@ -34,11 +34,11 @@
 #include <utility>
 #include <vector>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/memory/memory.h"
 #include "src/core/lib/surface/completion_queue.h"
 #include "src/core/util/crash.h"
+#include "src/core/util/grpc_check.h"
 #include "src/proto/grpc/testing/benchmark_service.grpc.pb.h"
 #include "test/cpp/qps/client.h"
 #include "test/cpp/qps/usage_timer.h"
@@ -86,7 +86,7 @@ class ClientRpcContextUnaryImpl : public ClientRpcContext {
         prepare_req_(prepare_req) {}
   ~ClientRpcContextUnaryImpl() override {}
   void Start(CompletionQueue* cq, const ClientConfig& config) override {
-    CHECK(!config.use_coalesce_api());  // not supported.
+    GRPC_CHECK(!config.use_coalesce_api());  // not supported.
     StartInternal(cq);
   }
   bool RunNextState(bool /*ok*/, HistogramEntry* entry) override {
@@ -480,7 +480,7 @@ class ClientRpcContextStreamingPingPongImpl : public ClientRpcContext {
     messages_issued_ = 0;
     coalesce_ = coalesce;
     if (coalesce_) {
-      CHECK_NE(messages_per_stream_, 0);
+      GRPC_CHECK_NE(messages_per_stream_, 0);
       context_.set_initial_metadata_corked(true);
     }
     stream_ = prepare_req_(stub_, &context_, cq);
@@ -548,7 +548,7 @@ class ClientRpcContextStreamingFromClientImpl : public ClientRpcContext {
         prepare_req_(prepare_req) {}
   ~ClientRpcContextStreamingFromClientImpl() override {}
   void Start(CompletionQueue* cq, const ClientConfig& config) override {
-    CHECK(!config.use_coalesce_api());  // not supported yet.
+    GRPC_CHECK(!config.use_coalesce_api());  // not supported yet.
     StartInternal(cq);
   }
   bool RunNextState(bool ok, HistogramEntry* entry) override {
@@ -680,7 +680,7 @@ class ClientRpcContextStreamingFromServerImpl : public ClientRpcContext {
         prepare_req_(prepare_req) {}
   ~ClientRpcContextStreamingFromServerImpl() override {}
   void Start(CompletionQueue* cq, const ClientConfig& config) override {
-    CHECK(!config.use_coalesce_api());  // not supported
+    GRPC_CHECK(!config.use_coalesce_api());  // not supported
     StartInternal(cq);
   }
   bool RunNextState(bool ok, HistogramEntry* entry) override {
@@ -795,7 +795,7 @@ class ClientRpcContextGenericStreamingImpl : public ClientRpcContext {
         prepare_req_(std::move(prepare_req)) {}
   ~ClientRpcContextGenericStreamingImpl() override {}
   void Start(CompletionQueue* cq, const ClientConfig& config) override {
-    CHECK(!config.use_coalesce_api());  // not supported yet.
+    GRPC_CHECK(!config.use_coalesce_api());  // not supported yet.
     StartInternal(cq, config.messages_per_stream());
   }
   bool RunNextState(bool ok, HistogramEntry* entry) override {
