@@ -24,7 +24,6 @@
 #include <set>
 #include <vector>
 
-#include "absl/log/check.h"
 #include "absl/log/log.h"
 #include "absl/memory/memory.h"
 #include "gmock/gmock.h"
@@ -32,6 +31,7 @@
 #include "opencensus/stats/testing/test_utils.h"
 #include "src/core/ext/filters/load_reporting/registered_opencensus_objects.h"
 #include "src/core/lib/iomgr/exec_ctx.h"
+#include "src/core/util/grpc_check.h"
 #include "src/cpp/server/load_reporter/constants.h"
 #include "test/core/test_util/port.h"
 #include "test/core/test_util/test_config.h"
@@ -59,7 +59,7 @@ class MockCensusViewProvider : public CensusViewProvider {
 
   const ViewDescriptor& FindViewDescriptor(const std::string& view_name) {
     auto it = view_descriptor_map().find(view_name);
-    CHECK(it != view_descriptor_map().end());
+    GRPC_CHECK(it != view_descriptor_map().end());
     return it->second;
   }
 };
