@@ -30,7 +30,7 @@ find . \( \( -name "*.cc" \) -or \( -name "*.h" \) \) \
         -a -not -wholename "./include/grpcpp/impl/sync.h" \
         -a -not -wholename "./src/core/util/sync.h" \
         -a -not -wholename "./src/core/util/sync_abseil.cc" \
-        -a -not -wholename "./test/core/transport/call_spine_benchmarks.h" \
+        -a -not -wholename "./test/core/call/call_spine_benchmarks.h" \
         -print0 |\
     xargs -0 grep -n "absl::Mutex" | \
     diff - /dev/null
